summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--drivers/acpi/scan.c12
1 files changed, 7 insertions, 5 deletions
diff --git a/drivers/acpi/scan.c b/drivers/acpi/scan.c
index 119c94093a13..7c26fed0bdf0 100644
--- a/drivers/acpi/scan.c
+++ b/drivers/acpi/scan.c
@@ -1051,13 +1051,15 @@ acpi_bus_add (
 	/*
 	 * Status
 	 * ------
 	 * See if the device is present.  We always assume that non-Device()
 	 * objects (e.g. thermal zones, power resources, processors, etc.) are
 	 * present, functioning, etc. (at least when parent object is present).
 	 * Note that _STA has a different meaning for some objects (e.g.
 	 * power resources) so we need to be careful how we use it.
 	 */
 	switch (type) {
+	case ACPI_BUS_TYPE_PROCESSOR:
 	case ACPI_BUS_TYPE_DEVICE:
 		result = acpi_bus_get_status(device);
 		if (ACPI_FAILURE(result) || !device->status.present) {
@@ -1051,13 +1051,15 @@ acpi_bus_add (
 	 * Status
 	 * ------
-	 * See if the device is present.  We always assume that non-Device()
-	 * objects (e.g. thermal zones, power resources, processors, etc.) are
-	 * present, functioning, etc. (at least when parent object is present).
-	 * Note that _STA has a different meaning for some objects (e.g.
-	 * power resources) so we need to be careful how we use it.
+	 * See if the device is present.  We always assume that non-Device
+	 * and non-Processor objects (e.g. thermal zones, power resources,
+	 * etc.) are present, functioning, etc. (at least when parent object
+	 * is present).  Note that _STA has a different meaning for some
+	 * objects (e.g. power resources) so we need to be careful how we use
+	 * it.
 	 */
 	switch (type) {